@@ -6,10 +6,12 @@ import logging
 from functools import wraps
 import tempfile
 from shutil import rmtree, copyfile
+import weakref
 
 import numpy as np
 import pyvista as pv
 
+import scooby
 import pyansys
 from pyansys import Archive
 from pyansys.mapdl_functions import _MapdlCommands
@@ -25,7 +27,8 @@ from pyansys.post import PostProcessing
 MATPLOTLIB_LOADED = True
 try:
     import matplotlib
-    matplotlib.use('tkagg')  # for windows
+    if os.name == 'nt':
+        matplotlib.use('tkagg')  # for windows
     import matplotlib.pyplot as plt
     import matplotlib.image as mpimg
 except:  # pragma: no cover
@@ -127,7 +130,7 @@ class _MapdlCore(_MapdlCommands):
         from pyansys.parameters import Parameters
         self._parameters = Parameters(self)
 
-        self._redirected_commands = {'*LIS': self._list}
+        self._redirected_commands = {'*LIS': weakref.ref(self._list)}
 
         if log_apdl:
             filename = os.path.join(self.directory, 'log.inp')
@@ -239,30 +242,30 @@ class _MapdlCore(_MapdlCommands):
 
         """
         def __init__(self, parent):
-            self._parent = parent
+            self._parent = weakref.ref(parent)
 
         def __enter__(self):
-            self._parent._log.debug('Entering non-interactive mode')
-            self._parent._store_commands = True
+            self._parent()._log.debug('Entering non-interactive mode')
+            self._parent()._store_commands = True
 
         def __exit__(self, *args):
-            self._parent._log.debug('Entering non-interactive mode')
-            self._parent._flush_stored()
+            self._parent()._log.debug('Entering non-interactive mode')
+            self._parent()._flush_stored()
 
     class _chain_commands:
         """Store MAPDL commands and send one chained command."""
 
         def __init__(self, parent):
-            self._parent = parent
+            self._parent = weakref.ref(parent)
 
         def __enter__(self):
-            self._parent._log.debug('Entering chained command mode')
-            self._parent._store_commands = True
+            self._parent()._log.debug('Entering chained command mode')
+            self._parent()._store_commands = True
 
         def __exit__(self, *args):
-            self._parent._log.debug('Entering chained command mode')
-            self._parent._chain_stored()
-            self._parent._store_commands = False
+            self._parent()._log.debug('Entering chained command mode')
+            self._parent()._chain_stored()
+            self._parent()._store_commands = False
 
     @property
     def last_response(self):
@@ -1081,27 +1084,31 @@ class _MapdlCore(_MapdlCommands):
         from pyansys.rst import Result
 
         if not self._local:
-            raise RuntimeError('Binary interface only available when result is local.')
-
-        if self._distributed_result_file and self._result_file:
-            result_path = self._distributed_result_file
-            result = Result(result_path, read_mesh=False)
-            if result._is_cyclic:
-                result_path = self._result_file
-            else:
-                # return the file with the last access time
-                filenames = [self._distributed_result_file, self._result_file]
-                result_path = last_created(filenames)
-
-        elif self._distributed_result_file:
-            result_path = self._distributed_result_file
-            result = Result(result_path, read_mesh=False)
-            if result._is_cyclic:
-                if not os.path.isfile(self._result_file):
-                    raise RuntimeError('Distributed Cyclic result not supported')
-                result_path = self._result_file
+            # download to temporary directory
+            save_path = os.path.join(tempfile.gettempdir(), 'ansys_tmp')
+            result_path = self.download_result(save_path)
         else:
-            result_path = self._result_file
+            if self._distributed_result_file and self._result_file:
+                result_path = self._distributed_result_file
+                result = Result(result_path, read_mesh=False)
+                if result._is_cyclic:
+                    result_path = self._result_file
+                else:
+                    # return the file with the last access time
+                    filenames = [self._distributed_result_file, self._result_file]
+                    result_path = last_created(filenames)
+                    if result_path is None:  # if same return result_file
+                        result_path = self._result_file
+
+            elif self._distributed_result_file:
+                result_path = self._distributed_result_file
+                result = Result(result_path, read_mesh=False)
+                if result._is_cyclic:
+                    if not os.path.isfile(self._result_file):
+                        raise RuntimeError('Distributed Cyclic result not supported')
+                    result_path = self._result_file
+            else:
+                result_path = self._result_file
 
         if result_path is None:
             raise FileNotFoundError('No result file(s) at %s' % self.directory)
@@ -1154,8 +1161,11 @@ class _MapdlCore(_MapdlCommands):
         if filename[-1].isnumeric():
             filename += '_'
 
-        rth_file = os.path.join(self.directory, '%s0.%s' % (filename, 'rth'))
-        rst_file = os.path.join(self.directory, '%s0.%s' % (filename, 'rst'))
+        rth_basename = '%s0.%s' % (filename, 'rth')
+        rst_basename = '%s0.%s' % (filename, 'rst')
+
+        rth_file = os.path.join(self.directory, rth_basename)
+        rst_file = os.path.join(self.directory, rst_basename)
         if os.path.isfile(rth_file) and os.path.isfile(rst_file):
             return last_created([rth_file, rst_file])
         elif os.path.isfile(rth_file):
@@ -1724,7 +1734,7 @@ class _MapdlCore(_MapdlCommands):
                 self._apdl_log.write('%s\n' % command)
 
         if command[:4] in self._redirected_commands:
-            function = self._redirected_commands[command[:4]]
+            function = self._redirected_commands[command[:4]]()
             return function(command)
 
         text = self._run(command, **kwargs)
@@ -1827,8 +1837,13 @@ class _MapdlCore(_MapdlCommands):
             raise ValueError('Expecting at least a 2D table, but input contains '
                              'only 1 dimension')
         self.dim(name, 'TABLE', array.shape[0], var1=var1, var2=var2, var3=var3)
-        filename = os.path.join(tempfile.gettempdir(), random_string() + '.txt')
+        base_name = random_string() + '.txt'
+        filename = os.path.join(tempfile.gettempdir(), base_name)
         np.savetxt(filename, array)
+
+        if not self._local:
+            self.upload(filename, progress_bar=False)
+            filename = base_name
         self.tread(name, filename)
 
     def _display_plot(self, *args, **kwargs):  # pragma: no cover
@@ -1890,7 +1905,10 @@ class _MapdlCore(_MapdlCommands):
             try:
                 self.exit()
             except Exception as e:
-                self._log.error('exit: %s', str(e))
+                try:  # logger might be closed
+                    self._log.error('exit: %s', str(e))
+                except:
+                    pass
 
     @supress_logging
     def get_array(self, entity='', entnum='', item1='', it1num='', item2='',
@@ -2018,8 +2036,11 @@ class _MapdlCore(_MapdlCommands):
                 plt.axis('off')
                 if self._show_matplotlib_figures:  # pragma: no cover
                     plt.show()  # consider in-line plotting
+                if scooby.in_ipython():
+                    from IPython.display import display
+                    display(plt.gcf())
             else:  # pragma: no cover
-                self._log.error('Unable to find screenshot at %s' % filename)
+                self._log.error('Unable to find screenshot at %s', filename)
 
     def _screenshot_path(self):
         """Return last filename based on the current jobname"""
